### 设置你的newtera-py Github仓库
Fork [newtera-py upstream](https://github.com/newtera/newtera-py/fork)源码仓库到你自己的仓库。

```sh
$ git clone https://github.com/$USER_ID/newtera-py
$ cd newtera-py
$ python setup.py install
...
```
